<img align="left" src="images/scp.png" width="180">

# Consulting


### Workbench + SCP Consulting = Awesome

Our experienced team can provide development and consulting services to help you effectively use Amazon’s Machine Learning services within your organization.

The popularity of cloud based Machine Learning services is booming. The problem many companies face is how that capability gets effectively used and harnessed to drive real business decisions and provide concrete value for their organization.

Using Workbench will minimizize the time and manpower needed to incorporate AWS ML into your organization. If your company would like to be a Workbench Alpha Tester, contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com).

### Typical Engagements
Workbench clients typically want a tailored web_interface that helps to drive business decisions and provides value for their organization.

- Workbench components provide a set of classes and transforms the will dramatically **reduce time** and **increase productivity** when building AWS ML Systems.
- Workbench enables rapid prototyping via it's **light paths** and provides AWS production workflows on **large scale data** through it's **heavy paths**.
- Rapid Prototyping is typically done via these steps.
 
  1. Quick Construction of Web Interface (***tailored***)
  2. Custom Components (***tailored***)
  3. Demo/Review the Application with the Client
  4. Get Feedback/Changes/Improvements
  5. Goto Step 1

- When the client is happy/excited about the ProtoType we then **bolt down** the system, test the heavy paths, review AWS access, security and ensure 'least privileged' roles and policies.

Contact us for a **free** initial consultation on how we can accelerate the use of AWS ML at your company [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com).

